@@ -1,7 +1,6 @@
 /* man.c: How to read and format man files.
 
-   Copyright 1995-2019 Free Software Foundation, 
-   Inc.
+   Copyright 1995-2022 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -32,6 +31,7 @@
 #include "nodes.h"
 #include "man.h"
 #include "variables.h"
+#include "util.h"
 
 #if !defined (_POSIX_VERSION)
 #define pid_t int
@@ -56,12 +56,75 @@ static char const * const exec_extensions[] = { "", NULL };
 static REFERENCE **xrefs_of_manpage (NODE *node);
 static char *read_from_fd (int fd);
 static char *get_manpage_contents (char *pagename);
+static char *find_man_formatter (void);
 
 /* We store the contents of retrieved man pages in here. */
 static NODE **manpage_nodes = 0;
 size_t manpage_node_index = 0;
 size_t manpage_node_slots = 0;
 
+#if PIPE_USE_FORK
+
+/* Check if a man page exists.  Use "man -w" for this rather than getting
+   the contents of the man page.  This is faster if we are running
+   "info --where" and we don't need the contents. */
+int
+check_manpage_node (char *pagename)
+{
+  pid_t child;
+  int pid_status = 0;
+  NODE *man_node;
+
+  child = fork ();
+  if (child == -1)
+    return 0; /* couldn't fork */
+
+  if (!child)
+    {
+      char *formatter;
+      (void)! freopen (NULL_DEVICE, "w", stdout);
+      (void)! freopen (NULL_DEVICE, "w", stderr);
+      /* avoid "unused result" warning with ! operator */
+      formatter = find_man_formatter();
+      if (!formatter)
+        exit (1);
+      execl (formatter, formatter, "-w", pagename, (void *) 0);
+      exit (2); /* exec failed */
+    }
+  else
+    {
+      wait (&pid_status);
+    }
+
+  if (pid_status != 2)
+    return !pid_status;
+
+  /* Possibly "man -w" wasn't recognized. */
+  man_node = get_manpage_node (pagename);
+  if (man_node)
+    {
+      free (man_node);
+      return 1;
+    }
+  return 0;
+}
+
+#else /* !PIPE_USE_FORK */
+
+int
+check_manpage_node (char *pagename)
+{
+  NODE *man_node = get_manpage_node (pagename);
+  if (man_node)
+    {
+      free (man_node);
+      return 1;
+    }
+  return 0;
+}
+
+#endif /* !PIPE_USE_FORK */
+
 NODE *
 get_manpage_node (char *pagename)
 {
@@ -170,9 +233,17 @@ executable_file_in_path (char *filename, char *path)
 static char *
 find_man_formatter (void)
 {
-  char *man_command = getenv ("INFO_MAN_COMMAND");
-  return man_command ? man_command :
-                       executable_file_in_path ("man", getenv ("PATH"));
+  static char *man_formatter;
+  char *man_command;
+
+  if (man_formatter)
+    return man_formatter;
+
+  man_command = getenv ("INFO_MAN_COMMAND");
+  man_formatter = man_command ? man_command
+                    : executable_file_in_path ("man", getenv ("PATH"));
+
+  return man_formatter;
 }
 
 static char *manpage_pagename = NULL;
@@ -302,11 +373,16 @@ get_manpage_from_formatter (char *formatter_args[])
   pid_t child;
   int formatter_status = 0;
 
+  putenv ("MAN_KEEP_FORMATTING=1"); /* Get codes for bold etc. */
+  putenv ("GROFF_SGR=1"); /* for Debian whose man outputs
+                             'overstrike' sequences without this */
+
   /* Open a pipe to this program, read the output, and save it away
      in FORMATTED_PAGE.  The reader end of the pipe is pipes[0]; the
      writer end is pipes[1]. */
 #if PIPE_USE_FORK
-  pipe (pipes);
+  if (pipe (pipes) == -1)
+    return 0; /* Creating pipe failed. */
 
   child = fork ();
   if (child == -1)
@@ -325,8 +401,9 @@ get_manpage_from_formatter (char *formatter_args[])
     { /* In the child, close the read end of the pipe, make the write end
          of the pipe be stdout, and execute the man page formatter. */
       close (pipes[0]);
-      freopen (NULL_DEVICE, "w", stderr);
-      freopen (NULL_DEVICE, "r", stdin);
+      (void)! freopen (NULL_DEVICE, "w", stderr);
+      (void)! freopen (NULL_DEVICE, "r", stdin);
+      /* avoid "unused result" warning with ! operator */
       dup2 (pipes[1], fileno (stdout));
 
       execv (formatter_args[0], formatter_args);
