@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright (C) 2014, 2015 Free Software Foundation, Inc.
+# Copyright (C) 2014-2019 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,5 +18,5 @@ srcdir=${srcdir:-.}
 . $srcdir/t/Init-test.inc
 
 # Follow a menu in a file
-$GINFO --output - file-menu 'First entry' | grep 'Arrived at Node 1.'
+$ginfo --output - file-menu 'First entry' | grep 'Arrived at Node 1.'
 
