@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright (C) 2015 Free Software Foundation, Inc.
+# Copyright (C) 2015-2019 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,23 +16,22 @@
 
 srcdir=${srcdir:-.}
 . $srcdir/t/Init-test.inc
-. $t/Init-inter.inc
 
 run_ginfo -f xref_to_anchor
 # Follow cross-reference to an anchor
-printf '\t\r' >$PTY_TYPE
+printf '\t\r' >&7
 
 # Follow the cross-reference on the line after the anchor
-printf '\6\6\rDq' >$PTY_TYPE
+printf '\6\6\rDq' >&7
 
-. $t/Timeout-test.inc
+timeout_test
 
-if test ! -f $GINFO_OUTPUT; then
-  RETVAL=1
+if test ! -f $ginfo_output; then
+  retval=1
 else
   # Return non-zero (test failure) if files differ
-  diff $GINFO_OUTPUT $t/node-target
-  RETVAL=$?
+  diff $ginfo_output $t/node-target
+  retval=$?
 fi
 
 cleanup
