@@ -1,8 +1,6 @@
 /* terminal.h -- The external interface to terminal I/O.
-   $Id: terminal.h 5337 2013-08-22 17:54:06Z karl $
 
-   Copyright 1993, 1996, 1997, 2001, 2002, 2004, 2007, 2013
-   Free Software Foundation, Inc.
+   Copyright 1993-2022 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -35,9 +33,6 @@ extern int screenwidth, screenheight;
 /* Non-zero means this terminal can't really do anything. */
 extern int terminal_is_dumb_p;
 
-/* Non-zero means that this terminal has a meta key. */
-extern int terminal_has_meta_p;
-
 /* Non-zero means that this terminal can produce a visible bell. */
 extern int terminal_has_visible_bell_p;
 
@@ -47,11 +42,13 @@ extern int terminal_use_visible_bell_p;
 /* Non-zero means that this terminal can scroll lines up and down. */
 extern int terminal_can_scroll;
 
+/* Non-zero means that this terminal can scroll within a restricted region. */
+extern int terminal_can_scroll_region;
+
 /* Initialize the terminal which is known as TERMINAL_NAME.  If this terminal
    doesn't have cursor addressability, TERMINAL_IS_DUMB_P becomes non-zero.
    The variables SCREENHEIGHT and SCREENWIDTH are set to the dimensions that
-   this terminal actually has.  The variable TERMINAL_HAS_META_P becomes non-
-   zero if this terminal supports a Meta key. */
+   this terminal actually has. */
 extern void terminal_initialize_terminal (char *terminal_name);
 extern VFunction *terminal_initialize_terminal_hook;
 
@@ -61,7 +58,7 @@ extern void terminal_get_screen_size (void);
 extern VFunction *terminal_get_screen_size_hook;
 
 /* Save and restore tty settings. */
-extern void terminal_prep_terminal (void);
+extern int terminal_prep_terminal (void);
 extern void terminal_unprep_terminal (void);
 
 extern VFunction *terminal_prep_terminal_hook;
@@ -107,6 +104,20 @@ extern VFunction *terminal_begin_inverse_hook;
 extern void terminal_end_inverse (void);
 extern VFunction *terminal_end_inverse_hook;
 
+/* Turn on standout mode if possible. */
+extern void terminal_begin_standout (void);
+extern VFunction *terminal_begin_standout_hook;
+
+/* Turn off standout mode if possible. */
+extern void terminal_end_standout (void);
+extern VFunction *terminal_end_standout_hook;
+
+/* Turn on and off underline mode if possible. */
+void terminal_begin_underline (void);
+extern VFunction *terminal_begin_underline_hook;
+void terminal_end_underline (void);
+extern VFunction *terminal_end_underline_hook;
+
 /* Scroll an area of the terminal, starting with the region from START
    to END, AMOUNT lines.  If AMOUNT is negative, the lines are scrolled
    towards the top of the screen, else they are scrolled towards the
@@ -114,6 +125,8 @@ extern VFunction *terminal_end_inverse_hook;
 extern void terminal_scroll_terminal (int start, int end, int amount);
 extern VFunction *terminal_scroll_terminal_hook;
 
+extern void terminal_scroll_region (int start, int end, int amount);
+
 /* Ring the terminal bell.  The bell is run visibly if it both has one and
    terminal_use_visible_bell_p is non-zero. */
 extern void terminal_ring_bell (void);
@@ -123,7 +136,45 @@ extern VFunction *terminal_ring_bell_hook;
 extern char *term_ku, *term_kd, *term_kr, *term_kl;
 extern char *term_kP, *term_kN;
 extern char *term_ke, *term_kh;
-extern char *term_kx, *term_ki;
-extern char *term_kD;
+extern char *term_kD, *term_ki;
+extern char *term_kB;
+
+extern char *term_so, *term_se;
+
+#define MP_NONE 0
+#define MP_NORMAL_TRACKING 1
+extern int mouse_protocol;
+
+#define COLOUR_MASK             000000000017
+#define COLOUR_BLACK    (8 + 0)
+#define COLOUR_RED      (8 + 1)
+#define COLOUR_GREEN    (8 + 2)
+#define COLOUR_YELLOW   (8 + 3)
+#define COLOUR_BLUE     (8 + 4)
+#define COLOUR_MAGENTA  (8 + 5)
+#define COLOUR_CYAN     (8 + 6)
+#define COLOUR_WHITE    (8 + 7)
+#define UNDERLINE_MASK          000000000020
+#define STANDOUT_MASK           000000000040
+#define BOLD_MASK               000000000100
+#define ZERO1_MASK              000000000200
+#define BLINK_MASK              000000000400
+#define BGCOLOUR_MASK           000000017000
+#define BGCOLOUR_BLACK    ((8 + 0) << 9)
+#define BGCOLOUR_RED      ((8 + 1) << 9)
+#define BGCOLOUR_GREEN    ((8 + 2) << 9)
+#define BGCOLOUR_YELLOW   ((8 + 3) << 9)
+#define BGCOLOUR_BLUE     ((8 + 4) << 9)
+#define BGCOLOUR_MAGENTA  ((8 + 5) << 9)
+#define BGCOLOUR_CYAN     ((8 + 6) << 9)
+#define BGCOLOUR_WHITE    ((8 + 7) << 9)
+#define ZERO2_MASK              000000100000
+#define ZERO3_MASK              000040000000
+#define ZERO4_MASK              020000000000
+
+/* ZEROi_MASK are always zero bits. */
+
+void terminal_switch_rendition (unsigned long desired_rendition);
+
 
 #endif /* !TERMINAL_H */
