@@ -58,7 +58,7 @@ xml_accents
 
 @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
-$VERSION = '7.0';
+$VERSION = '7.0.1';
 
 my %defaults = (
   'documentlanguage'     => undef,
@@ -1326,6 +1326,10 @@ sub table_item_content_tree($$$)
   my $contents = shift;
 
   my $table_item_tree = {'parent' => $element};
+
+  return $table_item_tree
+    if (!defined($contents));
+
   my $table_command = $element->{'parent'}->{'parent'}->{'parent'};
   if ($table_command->{'extra'}
      and $table_command->{'extra'}->{'command_as_argument'}) {
