@@ -1,23 +1,20 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'one_subsection_and_node'} = {
   'contents' => [
     {
-      'contents' => [],
-      'parent' => {},
-      'type' => 'text_root'
+      'type' => 'before_node_section'
     },
     {
       'args' => [
         {
           'contents' => [
             {
-              'parent' => {},
               'text' => 'one node'
             }
           ],
@@ -25,12 +22,10 @@ $result_trees{'one_subsection_and_node'} = {
             'spaces_after_argument' => '
 '
           },
-          'parent' => {},
           'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
-      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
@@ -46,19 +41,17 @@ $result_trees{'one_subsection_and_node'} = {
         'normalized' => 'one-node',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
         {
           'contents' => [
             {
-              'parent' => {},
               'text' => 'The subsection'
             }
           ],
@@ -66,36 +59,24 @@ $result_trees{'one_subsection_and_node'} = {
             'spaces_after_argument' => '
 '
           },
-          'parent' => {},
           'type' => 'line_arg'
         }
       ],
       'cmdname' => 'subsection',
-      'contents' => [],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'level' => 3,
-      'line_nr' => {
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 2,
         'macro' => ''
-      },
-      'number' => 1,
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
 };
-$result_trees{'one_subsection_and_node'}{'contents'}[0]{'parent'} = $result_trees{'one_subsection_and_node'};
-$result_trees{'one_subsection_and_node'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'one_subsection_and_node'}{'contents'}[1]{'args'}[0];
-$result_trees{'one_subsection_and_node'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'one_subsection_and_node'}{'contents'}[1];
 $result_trees{'one_subsection_and_node'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'one_subsection_and_node'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'one_subsection_and_node'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'one_subsection_and_node'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'one_subsection_and_node'}{'contents'}[1]{'parent'} = $result_trees{'one_subsection_and_node'};
-$result_trees{'one_subsection_and_node'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'one_subsection_and_node'}{'contents'}[2]{'args'}[0];
-$result_trees{'one_subsection_and_node'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'one_subsection_and_node'}{'contents'}[2];
-$result_trees{'one_subsection_and_node'}{'contents'}[2]{'parent'} = $result_trees{'one_subsection_and_node'};
 
 $result_texis{'one_subsection_and_node'} = '@node one node
 @subsection The subsection
@@ -107,49 +88,48 @@ $result_texts{'one_subsection_and_node'} = '1 The subsection
 ';
 
 $result_sectioning{'one_subsection_and_node'} = {
-  'level' => 2,
-  'section_childs' => [
-    {
-      'cmdname' => 'subsection',
-      'extra' => {
-        'associated_node' => {
-          'cmdname' => 'node',
-          'extra' => {
-            'normalized' => 'one-node',
-            'spaces_before_argument' => ' '
+  'structure' => {
+    'section_childs' => [
+      {
+        'cmdname' => 'subsection',
+        'extra' => {
+          'associated_node' => {
+            'cmdname' => 'node',
+            'extra' => {
+              'normalized' => 'one-node'
+            }
           }
         },
-        'spaces_before_argument' => ' '
-      },
-      'level' => 3,
-      'number' => 1,
-      'section_up' => {}
-    }
-  ]
+        'structure' => {
+          'section_level' => 3,
+          'section_number' => 1,
+          'section_up' => {}
+        }
+      }
+    ],
+    'section_level' => 2
+  }
 };
-$result_sectioning{'one_subsection_and_node'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'one_subsection_and_node'};
+$result_sectioning{'one_subsection_and_node'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'one_subsection_and_node'};
 
 $result_nodes{'one_subsection_and_node'} = {
   'cmdname' => 'node',
   'extra' => {
     'associated_section' => {
       'cmdname' => 'subsection',
-      'extra' => {
-        'spaces_before_argument' => ' '
-      },
-      'level' => 3,
-      'number' => 1
+      'extra' => {},
+      'structure' => {
+        'section_number' => 1
+      }
     },
-    'normalized' => 'one-node',
-    'spaces_before_argument' => ' '
+    'normalized' => 'one-node'
   }
 };
 
 $result_menus{'one_subsection_and_node'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'one-node',
-    'spaces_before_argument' => ' '
+    'normalized' => 'one-node'
   }
 };
 
@@ -192,7 +172,7 @@ $result_converted_errors{'info'}->{'one_subsection_and_node'} = [
 
 
 
-$result_converted{'html'}->{'one_subsection_and_node'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
+$result_converted{'html'}->{'one_subsection_and_node'} = '<!DOCTYPE html>
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -206,33 +186,14 @@ $result_converted{'html'}->{'one_subsection_and_node'} = '<!DOCTYPE html PUBLIC
 <meta name="viewport" content="width=device-width,initial-scale=1">
 
 <link href="#one-node" rel="start" title="one node">
-<style type="text/css">
-<!--
-a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
-a.summary-letter {text-decoration: none}
-blockquote.indentedblock {margin-right: 0em}
-div.display {margin-left: 3.2em}
-div.example {margin-left: 3.2em}
-kbd {font-style: oblique}
-pre.display {font-family: inherit}
-pre.format {font-family: inherit}
-pre.menu-comment {font-family: serif}
-pre.menu-preformatted {font-family: serif}
-span.nolinebreak {white-space: nowrap}
-span.roman {font-family: initial; font-weight: normal}
-span.sansserif {font-family: sans-serif; font-weight: normal}
-span:hover a.copiable-anchor {visibility: visible}
-ul.no-bullet {list-style: none}
--->
-</style>
 
 
 </head>
 
 <body lang="en">
-<div class="subsection" id="one-node">
-<span id="The-subsection"></span><h4 class="subsection">1 The subsection</h4>
-<hr></div>
+<div class="subsection-level-extent" id="one-node">
+<h4 class="subsection" id="The-subsection">1 The subsection</h4>
+</div>
 
 
 
